Struct datafusion_flight_sql_server::state::QueryHandle
source · pub struct QueryHandle { /* private fields */ }Expand description
Represents a query handle for use in prepared statements. All state required to run the prepared statement is passed back and forth to the client, so any service instance can run it
Implementations